@@ -1,5 +1,5 @@
 lndIWishart=
-function(nu,S,IW)
+function(nu,V,IW)
 {
 # 
 # P. Rossi 12/04
@@ -9,17 +9,17 @@ function(nu,S,IW)
 #
 # arguments:
 #   nu is d. f. parm
-#   S is location matrix
+#   V is location matrix
 #   IW is the value at which the density should be evaluated
 #
 # output:
 #   value of log density
 #
-# note: in this parameterization, E[IW]=S/(nu-k-1)
+# note: in this parameterization, E[IW]=V/(nu-k-1)
 #
-k=ncol(S)
+k=ncol(V)
 Uiw=chol(IW)
-lndetSd2=sum(log(diag(chol(S))))
+lndetVd2=sum(log(diag(chol(V))))
 lndetIWd2=sum(log(diag(Uiw)))
 #
 # first evaluate constant
@@ -27,5 +27,5 @@ lndetIWd2=sum(log(diag(Uiw)))
 const=((nu*k)/2)*log(2)+((k*(k-1))/4)*log(pi)
 arg=(nu+1-c(1:k))/2
 const=const+sum(lgamma(arg))
-return(-const+nu*lndetSd2-(nu+k+1)*lndetIWd2-.5*sum(diag(S%*%chol2inv(Uiw))))
+return(-const+nu*lndetVd2-(nu+k+1)*lndetIWd2-.5*sum(diag(V%*%chol2inv(Uiw))))
 }
